body {
	margin: 0;
	/*background-color: #1A8FCF;*/
	overflow: hidden;
	/*background-image: -webkit-linear-gradient(#0aa8ee, #070a41);*/
	background-image: -webkit-linear-gradient(#0aa8ee, #fffcff);
	color: #fff;
	font-family: Monospace;
	font-size: 13px;
	line-height: 24px;
}

a {
	color: #FFFFFF;
	text-decoration: none;
}

a:hover {
	text-decoration: underline;
}

button {
	cursor: pointer;
	text-transform: uppercase;
}

canvas {
	display: block;
}

#info {
	position: absolute;
	top: 0px;
	width: 100%;
	padding: 10px;
	box-sizing: border-box;
	text-align: center;
	z-index: 1; /* TODO Solve this in HTML */
}

.dg.ac {
	z-index: 2 !important; /* TODO Solve this in HTML */
}
